==> sat4j_2.0.4.orig.tar.gz: sat4j-2.0.4/org.sat4j.pb/src/main/java/org/sat4j/pb/core/PBSolverResolution.java <==
/*******************************************************************************
* SAT4J: a SATisfiability library for Java Copyright (C) 2004-2008 Daniel Le Berre
*
* All rights reserved. This program and the accompanying materials
* are made available under the terms of the Eclipse Public License v1.0
* which accompanies this distribution, and is available at
* http://www.eclipse.org/legal/epl-v10.html
*
* Alternatively, the contents of this file may be used under the terms of
* either the GNU Lesser General Public License Version 2.1 or later (the
* "LGPL"), in which case the provisions of the LGPL are applicable instead
* of those above. If you wish to allow use of your version of this file only
* under the terms of the LGPL, and not to allow others to use your version of
* this file under the terms of the EPL, indicate your decision by deleting
* the provisions above and replace them with the notice and other provisions
* required by the LGPL. If you do not delete the provisions above, a recipient
* may use your version of this file under the terms of the EPL or the LGPL.
* 
* Based on the pseudo boolean algorithms described in:
* A fast pseudo-Boolean constraint solver Chai, D.; Kuehlmann, A.
* Computer-Aided Design of Integrated Circuits and Systems, IEEE Transactions on
* Volume 24, Issue 3, March 2005 Page(s): 305 - 317
* 
* and 
* Heidi E. Dixon, 2004. Automating Pseudo-Boolean Inference within a DPLL 
* Framework. Ph.D. Dissertation, University of Oregon.
*******************************************************************************/
package org.sat4j.pb.core;

import org.sat4j.minisat.core.AssertingClauseGenerator;
import org.sat4j.minisat.core.ILits;
import org.sat4j.minisat.core.IOrder;
import org.sat4j.minisat.core.LearningStrategy;
import org.sat4j.minisat.core.RestartStrategy;
import org.sat4j.minisat.core.SearchParams;

public class PBSolverResolution extends PBSolver<ILits> {

    /**
     * 
     */
    private static final long serialVersionUID = 1L;

    public PBSolverResolution(
            AssertingClauseGenerator acg,
            LearningStrategy<ILits, PBDataStructureFactory<ILits>> learner,
            PBDataStructureFactory<ILits> dsf,
            SearchParams params, IOrder<ILits> order,
            RestartStrategy restarter) {
        super(acg, learner, dsf, params, order, restarter);
    }

    public PBSolverResolution(
            AssertingClauseGenerator acg,
            LearningStrategy<ILits, PBDataStructureFactory<ILits>> learner,
            PBDataStructureFactory<ILits> dsf,
            IOrder<ILits> order, RestartStrategy restarter) {
        super(acg, learner, dsf, order, restarter);
    }




}

==> sat4j_2.1.1.orig.tar.gz: sat4j-2.1.1/org.sat4j.pb/src/main/java/org/sat4j/pb/core/PBSolverResolution.java <==
/*******************************************************************************
* SAT4J: a SATisfiability library for Java Copyright (C) 2004-2008 Daniel Le Berre
*
* All rights reserved. This program and the accompanying materials
* are made available under the terms of the Eclipse Public License v1.0
* which accompanies this distribution, and is available at
* http://www.eclipse.org/legal/epl-v10.html
*
* Alternatively, the contents of this file may be used under the terms of
* either the GNU Lesser General Public License Version 2.1 or later (the
* "LGPL"), in which case the provisions of the LGPL are applicable instead
* of those above. If you wish to allow use of your version of this file only
* under the terms of the LGPL, and not to allow others to use your version of
* this file under the terms of the EPL, indicate your decision by deleting
* the provisions above and replace them with the notice and other provisions
* required by the LGPL. If you do not delete the provisions above, a recipient
* may use your version of this file under the terms of the EPL or the LGPL.
* 
* Based on the pseudo boolean algorithms described in:
* A fast pseudo-Boolean constraint solver Chai, D.; Kuehlmann, A.
* Computer-Aided Design of Integrated Circuits and Systems, IEEE Transactions on
* Volume 24, Issue 3, March 2005 Page(s): 305 - 317
* 
* and 
* Heidi E. Dixon, 2004. Automating Pseudo-Boolean Inference within a DPLL 
* Framework. Ph.D. Dissertation, University of Oregon.
*******************************************************************************/
package org.sat4j.pb.core;

import org.sat4j.minisat.core.AssertingClauseGenerator;
import org.sat4j.minisat.core.IOrder;
import org.sat4j.minisat.core.LearningStrategy;
import org.sat4j.minisat.core.RestartStrategy;
import org.sat4j.minisat.core.SearchParams;

public class PBSolverResolution extends PBSolver {

    /**
     * 
     */
    private static final long serialVersionUID = 1L;

    public PBSolverResolution(
            AssertingClauseGenerator acg,
            LearningStrategy<PBDataStructureFactory> learner,
            PBDataStructureFactory dsf,
            SearchParams params, IOrder order,
            RestartStrategy restarter) {
        super(acg, learner, dsf, params, order, restarter);
    }

    public PBSolverResolution(
            AssertingClauseGenerator acg,
            LearningStrategy<PBDataStructureFactory> learner,
            PBDataStructureFactory dsf,
            IOrder order, RestartStrategy restarter) {
        super(acg, learner, dsf, order, restarter);
    }




}
